server

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 25, 2025 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(ctx context.Context, cfg *config.Config) error

Run builds SuhaibServer from the supplied configuration and serves traffic until the context is cancelled or a fatal error occurs.

func RunWithConfigFile

func RunWithConfigFile(ctx context.Context, configFilePath string) error

RunWithConfigFile loads the YAML configuration from the provided path and starts SuhaibServer. The call blocks until the provided context is cancelled or an error occurs.

Types

This section is empty.

Jump to